@@ -37,7 +37,7 @@ class Index extends BaseController {
         
         // load tags
         $tagsDao = new \daos\Tags();
-        $tags = $tagsDao->get();
+        $tags = $tagsDao->getWithUnread();
         
         // load items
         $itemsHtml = $this->loadItems($options, $tags);
@@ -45,9 +45,10 @@ class Index extends BaseController {
         
         // load stats
         $itemsDao = new \daos\Items();
-        $this->view->statsAll = $itemsDao->numberOfItems();
-        $this->view->statsUnread = $itemsDao->numberOfUnread();
-        $this->view->statsStarred = $itemsDao->numberOfStarred();
+        $stats = $itemsDao->stats();
+        $this->view->statsAll = $stats['total'];
+        $this->view->statsUnread = $stats['unread'];
+        $this->view->statsStarred = $stats['starred'];
         
         // prepare tags display list
         $tagsController = new \controllers\Tags();
@@ -55,7 +56,7 @@ class Index extends BaseController {
         
         // prepare sources display list
         $sourcesDao = new \daos\Sources();
-        $sources = $sourcesDao->get();
+        $sources = $sourcesDao->getWithUnread();
         $sourcesController = new \controllers\Sources();
         $this->view->sources = $sourcesController->renderSources($sources);
         
@@ -189,8 +190,22 @@ class Index extends BaseController {
         
         echo "finished";
     }
-    
-    
+
+    /*
+    * get the unread number of items for a windows 8 badge
+    * notification.
+    */
+    public function badge() {
+        // load stats
+        $itemsDao = new \daos\Items();
+        $this->view->statsUnread = $itemsDao->numberOfUnread();
+        echo $this->view->render('templates/badge.phtml');
+    }
+
+    public function win8Notifications() {
+        echo $this->view->render('templates/win8-notifications.phtml');
+    }
+
     /**
      * load items
      *
