@@ -35,7 +35,7 @@ class Items extends Database {
             $id = implode(",", $id);
         
         // i used string concatenation after validating $id
-        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET unread=0 WHERE id IN (' . $id . ')');
+        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET '.$this->stmt->isFalse('unread').' WHERE id IN (' . $id . ')');
     }
     
     
@@ -51,7 +51,7 @@ class Items extends Database {
         } else if(!is_numeric($id)) {
             return;
         }
-        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET unread=1 WHERE id IN (:id)',
+        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET '.$this->stmt->isTrue('unread').' WHERE id IN (:id)',
                     array(':id' => $id));
     }
     
@@ -63,7 +63,7 @@ class Items extends Database {
      * @param int $id the item
      */
     public function starr($id) {
-        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET starred=1 WHERE id=:id', 
+        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET '.$this->stmt->isTrue('starred').' WHERE id=:id',
                     array(':id' => $id));
     }
     
@@ -75,7 +75,7 @@ class Items extends Database {
      * @param int $id the item
      */
     public function unstarr($id) {
-        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET starred=0 WHERE id=:id',
+        \F3::get('db')->exec('UPDATE '.\F3::get('db_prefix').'items SET '.$this->stmt->isFalse('starred').' WHERE id=:id',
                     array(':id' => $id));
     }
     
@@ -150,6 +150,9 @@ class Items extends Database {
      */
     public function findAll($itemsInFeed) {
         $itemsFound = array();
+        if( count($itemsInFeed) < 1 )
+            return $itemsFound;
+
         array_walk($itemsInFeed, function( &$value ) { $value = \F3::get('db')->quote($value); });
         $query = 'SELECT uid AS uid FROM '.\F3::get('db_prefix').'items WHERE uid IN ('. implode(',', $itemsInFeed) .')';
         $res = \F3::get('db')->query($query);
@@ -192,11 +195,11 @@ class Items extends Database {
                 
         // only starred
         if(isset($options['type']) && $options['type']=='starred')
-            $where .= ' AND starred=1 ';
+            $where .= ' AND '.$this->stmt->isTrue('starred');
             
         // only unread
         else if(isset($options['type']) && $options['type']=='unread'){
-            $where .= ' AND unread=1 ';
+            $where .= ' AND '.$this->stmt->isTrue('unread');
             if(\F3::get('unread_order')=='asc'){
                 $order = 'ASC';
             }
@@ -213,7 +216,7 @@ class Items extends Database {
         if(isset($options['tag']) && strlen($options['tag'])>0) {
             $params[':tag'] = array( "%,".$options['tag'].",%" , \PDO::PARAM_STR );
             if ( \F3::get( 'db_type' ) == 'mysql' ) {
-              $where .= " AND ( CONCAT( ',' , sources.tags , ',' ) LIKE :tag ) ";
+              $where .= " AND ( CONCAT( ',' , sources.tags , ',' ) LIKE _utf8 :tag COLLATE utf8_bin ) ";
             } else {
               $where .= " AND ( (',' || sources.tags || ',') LIKE :tag ) ";
             }
@@ -242,7 +245,7 @@ class Items extends Database {
         $result = \F3::get('db')->exec('SELECT items.id
                    FROM '.\F3::get('db_prefix').'items AS items, '.\F3::get('db_prefix').'sources AS sources
                    WHERE items.source=sources.id '.$where.' 
-                   LIMIT ' . ($options['offset']+$options['items']) . ', 1', $params);
+                   LIMIT 1 OFFSET ' . ($options['offset']+$options['items']), $params);
         $this->hasMore = count($result);
 
         // get items from database
@@ -251,7 +254,7 @@ class Items extends Database {
                    FROM '.\F3::get('db_prefix').'items AS items, '.\F3::get('db_prefix').'sources AS sources
                    WHERE items.source=sources.id '.$where.' 
                    ORDER BY items.datetime '.$order.' 
-                   LIMIT ' . $options['offset'] . ', ' . $options['items'], $params);
+                   LIMIT ' . $options['items'] . ' OFFSET '. $options['offset'], $params);
     }
     
     
@@ -370,7 +373,7 @@ class Items extends Database {
         if(is_numeric($sourceid)===false)
             return false;
         
-        $res = \F3::get('db')->exec('SELECT icon FROM '.\F3::get('db_prefix').'items WHERE source=:sourceid AND icon!="" ORDER BY ID DESC LIMIT 0,1',
+        $res = \F3::get('db')->exec('SELECT icon FROM '.\F3::get('db_prefix').'items WHERE source=:sourceid AND icon!=\'\' AND icon IS NOT NULL ORDER BY ID DESC LIMIT 1',
                     array(':sourceid' => $sourceid));
         if(count($res)==1)
             return $res[0]['icon'];
@@ -379,17 +382,6 @@ class Items extends Database {
     }
     
     
-    /**
-     * returns the amount of entries in database
-     *
-     * @return int amount of entries in database
-     */
-    public function numberOfItems() {
-        $res = \F3::get('db')->exec('SELECT count(*) AS amount FROM '.\F3::get('db_prefix').'items');
-        return $res[0]['amount'];
-    }
-    
-    
     /**
      * returns the amount of entries in database which are unread
      *
@@ -398,53 +390,18 @@ class Items extends Database {
     public function numberOfUnread() {
         $res = \F3::get('db')->exec('SELECT count(*) AS amount
                    FROM '.\F3::get('db_prefix').'items 
-                   WHERE unread=1');
+                   WHERE '.$this->stmt->isTrue('unread'));
         return $res[0]['amount'];
     }
-    
+   
     
     /**
-     * returns the amount of entries in database which are starred
-     *
-     * @return int amount of entries in database which are starred
-     */
-    public function numberOfStarred() {
-        $res = \F3::get('db')->exec('SELECT count(*) AS amount
-                   FROM '.\F3::get('db_prefix').'items 
-                   WHERE starred=1');
-        return $res[0]['amount'];
+    * returns the amount of total, unread, starred entries in database
+    *
+    * @return array mount of total, unread, starred entries in database
+    */
+    public function stats() {
+        $res = \F3::get('db')->exec('SELECT COUNT(*) AS total, '.$this->stmt->sumBool('unread').' AS unread, '.$this->stmt->sumBool('starred').' AS starred FROM items;');
+        return $res[0];
     }
-    
-    
-    /**
-     * returns the amount of unread entries in database per tag
-     *
-     * @return int amount of entries in database per tag
-     */
-    public function numberOfUnreadForTag($tag) {
-        $select = 'SELECT count(*) AS amount FROM '.\F3::get('db_prefix').'items AS items, '.\F3::get('db_prefix').'sources AS sources';
-        $where = ' WHERE items.source=sources.id AND unread=1';
-        if ( \F3::get( 'db_type' ) == 'mysql' ) {
-            $where .= " AND ( CONCAT( ',' , sources.tags , ',' ) LIKE :tag ) ";
-        } else {
-            $where .= " AND ( (',' || sources.tags || ',') LIKE :tag ) ";
-        }
-        $res = \F3::get('db')->exec( $select . $where,
-            array(':tag' => "%,".$tag.",%"));
-        return $res[0]['amount'];
-    }
-    
-    
-    /**
-     * returns the amount of unread entries in database per source
-     *
-     * @return int amount of entries in database per tag
-     */
-    public function numberOfUnreadForSource($sourceid) {
-        $res = \F3::get('db')->exec(
-            'SELECT count(*) AS amount FROM '.\F3::get('db_prefix').'items WHERE source=:source AND unread=1',
-            array(':source' => $sourceid));
-        return $res[0]['amount'];
-    }
-
 }
