@@ -76,10 +76,11 @@ class Image {
      *
      * @return bool
      * @param string $url source url
+     * @param string $extension file extension of output file
      * @param int $width
      * @param int $height
      */
-    public function loadImage($url, $width=false, $height=false) {
+    public function loadImage($url, $extension='png', $width=false, $height=false) {
         // load image
         $data = @file_get_contents($url);
         if($data===false)
@@ -128,12 +129,18 @@ class Image {
         
         // resize
         if($width!==false && $height!==false) {
-            if($wideImage->getHeight()>$height || $wideImage->getWidth()>$width)
+            if(($height!==null && $wideImage->getHeight()>$height) ||
+               ($width!==null && $wideImage->getWidth()>$width))
                 $wideImage = $wideImage->resize($width, $height);
         }
         
-        // return image as png
-        $data = $wideImage->asString('png',0);
+        // return image as jpg or png
+        if($extension=='jpg') {
+            $data = $wideImage->asString('jpg', 75);
+        }
+        else {
+            $data = $wideImage->asString('png', 4, PNG_NO_FILTER);
+        }
         
         return $data;
     }
@@ -162,10 +169,11 @@ class Image {
         if($result==0)
             $result = preg_match('/<link [^>]*rel=("|\')icon\1.*>/Ui', $html, $match1);
         if($result>0) {
-            preg_match('/href=("|\')(.*)\1/Ui', $match1[0], $match2);
-            return $match2[2];
+            $result = preg_match('/href=("|\')(.+)\1/Ui', $match1[0], $match2);
+            if($result>0)
+                return $match2[2];
         }
         
         return false;
     }
-}
\ No newline at end of file
+}
