@@ -169,6 +169,8 @@ var selfoss = {
                 // update sources
                 selfoss.refreshSources(data.sources);
 
+                selfoss.setUnreadCount(data.unread);
+
                 // clean up
                 $('#content').removeClass('loading');
                 selfoss.activeAjaxReq = null;
@@ -179,7 +181,8 @@ var selfoss = {
                 else if (textStatus == "parsererror")
                     location.reload();
                 else if (errorThrown)
-                    selfoss.showError('Load list error: '+errorThrown);
+                    selfoss.showError('Load list error: '+
+                                      textStatus+' '+errorThrown);
             }
         });
     },
@@ -202,7 +205,8 @@ var selfoss = {
                 selfoss.events.navigation();
             },
             error: function(jqXHR, textStatus, errorThrown) {
-                selfoss.showError('Load tags error: '+errorThrown);
+                selfoss.showError('Load tags error: '+
+                                  textStatus+' '+errorThrown);
             },
             complete: function(jqXHR, textStatus) {
                 $('#nav-tags').removeClass('loading');
@@ -264,10 +268,10 @@ var selfoss = {
     
     
     /**
-     * anonymize links
+     * show error
      *
      * @return void
-     * @param parent element
+     * @param message string
      */
     showError: function(message) {
         if(typeof(message) == 'undefined') {
@@ -301,6 +305,19 @@ var selfoss = {
                 }
             }
         });
+    },
+
+    /**
+     * show the unread count in the document title
+     * 
+     * @param int unread
+     */
+    setUnreadCount: function(unread) {
+        if(unread>0) {
+            $(document).attr('title', 'selfoss ('+unread+')');
+        } else {
+            $(document).attr('title', 'selfoss');
+        }
     }
 
 };
